@@ -3,7 +3,7 @@
 ##############################################################################
 ##
 ##  Canon Inkjet Printer Driver for Linux
-##  Copyright CANON INC. 2001-2024
+##  Copyright CANON INC. 2001-2025
 ##
 ##  This program is free software; you can redistribute it and/or modify
 ##  it under the terms of the GNU General Public License as published by
@@ -20,10 +20,10 @@
 ##
 ##############################################################################
 
-C_version="6.80-1"
-C_copyright_end="2024"
+C_version="6.81-1"
+C_copyright_end="2025"
 C_default_system="deb"
-P_support_printer=("G4090" "G4080" "G3090" "G3080" "TS8800" "XK130")
+P_support_printer=("GX6100" "GX7100" "GX5100" "TR160" "BX110")
 
 L_INST_COM_01_01="Command executed = %s\n"
 
